@@ -337,8 +337,8 @@ cd_sensor_kind_to_string (CdSensorKind sensor_kind)
 		return "dummy";
 	if (sensor_kind == CD_SENSOR_KIND_HUEY)
 		return "huey";
-	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI)
-		return "color-munki";
+	if (sensor_kind == CD_SENSOR_KIND_COLOR_MUNKI_PHOTO)
+		return "color-munki-photo";
 	if (sensor_kind == CD_SENSOR_KIND_SPYDER)
 		return "spyder";
 	if (sensor_kind == CD_SENSOR_KIND_SPYDER2)
@@ -395,8 +395,9 @@ cd_sensor_kind_from_string (const gchar *sensor_kind)
 		return CD_SENSOR_KIND_DUMMY;
 	if (g_strcmp0 (sensor_kind, "huey") == 0)
 		return CD_SENSOR_KIND_HUEY;
-	if (g_strcmp0 (sensor_kind, "color-munki") == 0)
-		return CD_SENSOR_KIND_COLOR_MUNKI;
+	if (g_strcmp0 (sensor_kind, "color-munki") == 0 ||
+	    g_strcmp0 (sensor_kind, "color-munki-photo") == 0)
+		return CD_SENSOR_KIND_COLOR_MUNKI_PHOTO;
 	if (g_strcmp0 (sensor_kind, "spyder") == 0)
 		return CD_SENSOR_KIND_SPYDER;
 	if (g_strcmp0 (sensor_kind, "spyder2") == 0)
@@ -427,6 +428,8 @@ cd_sensor_kind_from_string (const gchar *sensor_kind)
 		return CD_SENSOR_KIND_COLORHUG;
 	if (g_strcmp0 (sensor_kind, "colorhug-spectro") == 0)
 		return CD_SENSOR_KIND_COLORHUG_SPECTRO;
+	if (g_strcmp0 (sensor_kind, "color-munki-smile") == 0)
+		return CD_SENSOR_KIND_COLOR_MUNKI_SMILE;
 	return CD_SENSOR_KIND_UNKNOWN;
 }
 
@@ -663,6 +666,57 @@ cd_profile_warning_from_string (const gchar *type)
 	return CD_PROFILE_WARNING_LAST;
 }
 
+/**
+ * cd_profile_quality_to_string:
+ *
+ * Converts a #CdProfileQuality to a string.
+ *
+ * Return value: identifier string
+ *
+ * Since: 0.1.27
+ **/
+const gchar *
+cd_profile_quality_to_string (CdProfileQuality quality_enum)
+{
+	const gchar *kind = NULL;
+	switch (quality_enum) {
+	case CD_PROFILE_QUALITY_LOW:
+		kind = "low";
+		break;
+	case CD_PROFILE_QUALITY_MEDIUM:
+		kind = "medium";
+		break;
+	case CD_PROFILE_QUALITY_HIGH:
+		kind = "high";
+		break;
+	default:
+		kind = "unknown";
+		break;
+	}
+	return kind;
+}
+
+/**
+ * cd_profile_quality_from_string:
+ *
+ * Converts a string to a #CdProfileQuality.
+ *
+ * Return value: enumerated value
+ *
+ * Since: 0.1.27
+ **/
+CdProfileQuality
+cd_profile_quality_from_string (const gchar *quality)
+{
+	if (g_strcmp0 (quality, "low") == 0)
+		return CD_PROFILE_QUALITY_LOW;
+	if (g_strcmp0 (quality, "medium") == 0)
+		return CD_PROFILE_QUALITY_MEDIUM;
+	if (g_strcmp0 (quality, "high") == 0)
+		return CD_PROFILE_QUALITY_HIGH;
+	return CD_PROFILE_QUALITY_LAST;
+}
+
 /**
  * cd_device_kind_to_profile_kind:
  * @device_kind: A #CdDeviceKind
