@@ -142,8 +142,8 @@ typedef enum {
 	CD_SENSOR_KIND_UNKNOWN,
 	CD_SENSOR_KIND_DUMMY,
 	CD_SENSOR_KIND_HUEY,
-	CD_SENSOR_KIND_COLOR_MUNKI,
-	CD_SENSOR_KIND_SPYDER,		/* not used since 0.1.16 */
+	CD_SENSOR_KIND_COLOR_MUNKI_PHOTO,
+	CD_SENSOR_KIND_SPYDER,			/* not used since 0.1.16 */
 	CD_SENSOR_KIND_DTP20,
 	CD_SENSOR_KIND_DTP22,
 	CD_SENSOR_KIND_DTP41,
@@ -152,16 +152,17 @@ typedef enum {
 	CD_SENSOR_KIND_SPECTRO_SCAN,
 	CD_SENSOR_KIND_I1_PRO,
 	CD_SENSOR_KIND_COLORIMTRE_HCFR,
-	CD_SENSOR_KIND_I1_DISPLAY3,	/* Since: 0.1.14 */
-	CD_SENSOR_KIND_COLORHUG,	/* Since: 0.1.15 */
-	CD_SENSOR_KIND_SPYDER2,		/* Since: 0.1.16 */
-	CD_SENSOR_KIND_SPYDER3,		/* Since: 0.1.16 */
-	CD_SENSOR_KIND_COLORHUG_SPECTRO,/* Since: 0.1.24 */
-	CD_SENSOR_KIND_I1_DISPLAY1,	/* Since: 0.1.25 */
-	CD_SENSOR_KIND_I1_DISPLAY2,	/* Since: 0.1.25 */
-	CD_SENSOR_KIND_DTP92,		/* Since: 0.1.25 */
-	CD_SENSOR_KIND_I1_MONITOR,	/* Since: 0.1.25 */
-	CD_SENSOR_KIND_SPYDER4,		/* Since: 0.1.26 */
+	CD_SENSOR_KIND_I1_DISPLAY3,		/* Since: 0.1.14 */
+	CD_SENSOR_KIND_COLORHUG,		/* Since: 0.1.15 */
+	CD_SENSOR_KIND_SPYDER2,			/* Since: 0.1.16 */
+	CD_SENSOR_KIND_SPYDER3,			/* Since: 0.1.16 */
+	CD_SENSOR_KIND_COLORHUG_SPECTRO,	/* Since: 0.1.24 */
+	CD_SENSOR_KIND_I1_DISPLAY1,		/* Since: 0.1.25 */
+	CD_SENSOR_KIND_I1_DISPLAY2,		/* Since: 0.1.25 */
+	CD_SENSOR_KIND_DTP92,			/* Since: 0.1.25 */
+	CD_SENSOR_KIND_I1_MONITOR,		/* Since: 0.1.25 */
+	CD_SENSOR_KIND_SPYDER4,			/* Since: 0.1.26 */
+	CD_SENSOR_KIND_COLOR_MUNKI_SMILE,	/* Since: 0.1.27 */
 	CD_SENSOR_KIND_LAST
 } CdSensorKind;
 
@@ -242,6 +243,22 @@ typedef enum {
 	CD_PROFILE_WARNING_LAST
 } CdProfileWarning;
 
+/**
+ * CdProfileQuality:
+ * @CD_PROFILE_QUALITY_LOW: Low quality profile, fast
+ * @CD_PROFILE_QUALITY_MEDIUM: Medium quality profile
+ * @CD_PROFILE_QUALITY_HIGH: High quality profile, slow
+ *
+ * The quality of the profile produced through calibration.
+ **/
+typedef enum {
+	CD_PROFILE_QUALITY_LOW,
+	CD_PROFILE_QUALITY_MEDIUM,
+	CD_PROFILE_QUALITY_HIGH,
+	/*< private >*/
+	CD_PROFILE_QUALITY_LAST
+} CdProfileQuality;
+
 /**
  * CdSensorError:
  * @CD_SENSOR_ERROR_NO_SUPPORT:		This action is unsupported on this hardware
@@ -381,6 +398,10 @@ typedef enum {
 #define CD_PROFILE_METADATA_CONNECTION_TYPE_HDMI	"hdmi"		/* Since: 0.1.16 */
 #define CD_PROFILE_METADATA_CONNECTION_TYPE_DISPLAYPORT	"displayport"	/* Since: 0.1.16 */
 #define CD_PROFILE_METADATA_LICENSE		"License"		/* Since: 0.1.25 */
+#define CD_PROFILE_METADATA_QUALITY		"Quality"		/* Since: 0.1.27 */
+#define CD_PROFILE_METADATA_QUALITY_LOW		"low"			/* Since: 0.1.27 */
+#define CD_PROFILE_METADATA_QUALITY_MEDIUM	"medium"		/* Since: 0.1.27 */
+#define CD_PROFILE_METADATA_QUALITY_HIGH	"high"			/* Since: 0.1.27 */
 
 /* defined in org.freedesktop.ColorManager.Profile.xml */
 #define CD_PROFILE_PROPERTY_FILENAME		"Filename"
@@ -422,6 +443,7 @@ typedef enum {
 #define CD_DEVICE_PROPERTY_SEAT			"Seat"
 #define CD_DEVICE_PROPERTY_PROFILING_INHIBITORS	"ProfilingInhibitors"
 #define CD_DEVICE_PROPERTY_ENABLED		"Enabled"
+#define CD_DEVICE_PROPERTY_EMBEDDED		"Embedded"
 
 /* defined in org.freedesktop.ColorManager.Sensor.xml */
 #define CD_SENSOR_PROPERTY_ID			"SensorId"
@@ -461,6 +483,8 @@ const gchar	*cd_standard_space_to_string		(CdStandardSpace	 standard_space);
 CdStandardSpace	 cd_standard_space_from_string		(const gchar		*standard_space);
 const gchar	*cd_profile_warning_to_string		(CdProfileWarning	 kind_enum);
 CdProfileWarning cd_profile_warning_from_string		(const gchar		*type);
+const gchar	*cd_profile_quality_to_string		(CdProfileQuality	 quality_enum);
+CdProfileQuality cd_profile_quality_from_string		(const gchar		*quality);
 CdProfileKind	 cd_device_kind_to_profile_kind		(CdDeviceKind		 device_kind);
 
 const gchar	*cd_sensor_error_to_string		(CdSensorError		 error_enum);
