@@ -73,6 +73,7 @@ struct _CdDevicePrivate
 	gboolean			 require_modified_signal;
 	gboolean			 is_virtual;
 	gboolean			 enabled;
+	gboolean			 embedded;
 	GHashTable			*metadata;
 	guint				 owner;
 	gchar				*seat;
@@ -900,9 +901,13 @@ cd_device_set_model (CdDevice *device, const gchar *model)
 	/* remove insanities */
 	tmp = g_string_new (model);
 
-	/* are we really a webcam */
-	if (g_strcmp0 (priv->kind, "webcam") == 0)
-		g_string_assign (tmp, "Webcam");
+	/* remove the kind suffix */
+	if (g_strcmp0 (priv->kind, "printer") == 0)
+		cd_device_string_remove_suffix (tmp->str, "Printer");
+	if (g_strcmp0 (priv->kind, "display") == 0) {
+		cd_device_string_remove_suffix (tmp->str, "Monitor");
+		cd_device_string_remove_suffix (tmp->str, "Screen");
+	}
 
 	/* okay, we're done now */
 	g_free (priv->model);
@@ -958,6 +963,8 @@ cd_device_set_property_internal (CdDevice *device,
 	} else if (g_strcmp0 (property, CD_DEVICE_PROPERTY_SEAT) == 0) {
 		g_free (priv->seat);
 		priv->seat = g_strdup (value);
+	} else if (g_strcmp0 (property, CD_DEVICE_PROPERTY_EMBEDDED) == 0) {
+		priv->embedded = TRUE;
 	} else {
 		/* add to metadata */
 		is_metadata = TRUE;
@@ -1566,7 +1573,6 @@ cd_device_dbus_get_property (GDBusConnection *connection_, const gchar *sender,
 {
 	CdDevice *device = CD_DEVICE (user_data);
 	CdDevicePrivate *priv = device->priv;
-	gboolean ret;
 	gchar **bus_names = NULL;
 	GVariant *retval = NULL;
 
@@ -1617,18 +1623,7 @@ cd_device_dbus_get_property (GDBusConnection *connection_, const gchar *sender,
 		goto out;
 	}
 	if (g_strcmp0 (property_name, CD_DEVICE_PROPERTY_PROFILES) == 0) {
-
-		/* are we profiling? */
-		ret = cd_inhibit_valid (priv->inhibit);
-		if (!ret) {
-			g_debug ("CdDevice: returning no profiles for profiling");
-			retval = g_variant_new ("ao", NULL);
-		} else if (!priv->enabled) {
-			g_debug ("CdDevice: returning no profiles as device disabled");
-			retval = g_variant_new ("ao", NULL);
-		} else {
-			retval = cd_device_get_profiles_as_variant (device);
-		}
+		retval = cd_device_get_profiles_as_variant (device);
 		goto out;
 	}
 	if (g_strcmp0 (property_name, CD_DEVICE_PROPERTY_METADATA) == 0) {
@@ -1647,6 +1642,10 @@ cd_device_dbus_get_property (GDBusConnection *connection_, const gchar *sender,
 		retval = cd_device_get_nullable_for_string (priv->seat);
 		goto out;
 	}
+	if (g_strcmp0 (property_name, CD_DEVICE_PROPERTY_EMBEDDED) == 0) {
+		retval = g_variant_new_boolean (priv->embedded);
+		goto out;
+	}
 	if (g_strcmp0 (property_name, CD_DEVICE_PROPERTY_PROFILING_INHIBITORS) == 0) {
 		bus_names = cd_inhibit_get_bus_names (priv->inhibit);
 		retval = g_variant_new_strv ((const gchar * const *) bus_names, -1);
