@@ -24,6 +24,7 @@
 #include <gio/gio.h>
 #include <glib-object.h>
 #include <sqlite3.h>
+#include <syslog.h>
 
 #include "cd-common.h"
 #include "cd-mapping-db.h"
@@ -65,12 +66,13 @@ cd_mapping_db_load (CdMappingDb *mdb,
 		goto out;
 
 	g_debug ("CdMappingDb: trying to open database '%s'", filename);
+	syslog (LOG_INFO, "Using mapping database file %s", filename);
 	rc = sqlite3_open (filename, &mdb->priv->db);
 	if (rc != SQLITE_OK) {
 		ret = FALSE;
 		g_set_error (error,
-			     CD_MAIN_ERROR,
-			     CD_MAIN_ERROR_FAILED,
+			     CD_CLIENT_ERROR,
+			     CD_CLIENT_ERROR_INTERNAL,
 			     "Can't open database: %s\n",
 			     sqlite3_errmsg (mdb->priv->db));
 		sqlite3_close (mdb->priv->db);
@@ -130,8 +132,8 @@ cd_mapping_db_empty (CdMappingDb *mdb,
 	if (rc != SQLITE_OK) {
 		ret = FALSE;
 		g_set_error (error,
-			     CD_MAIN_ERROR,
-			     CD_MAIN_ERROR_FAILED,
+			     CD_CLIENT_ERROR,
+			     CD_CLIENT_ERROR_INTERNAL,
 			     "SQL error: %s",
 			     error_msg);
 		sqlite3_free (error_msg);
@@ -162,16 +164,16 @@ cd_mapping_db_add (CdMappingDb *mdb,
 	g_debug ("CdMappingDb: add %s<=>%s",
 		 device_id, profile_id);
 	timestamp = g_get_real_time ();
-	statement = g_strdup_printf ("INSERT INTO mappings (device, profile, timestamp) "
-				     "VALUES ('%s', '%s', %"G_GINT64_FORMAT")",
+	statement = sqlite3_mprintf ("INSERT INTO mappings (device, profile, timestamp) "
+				     "VALUES ('%q', '%q', %"G_GINT64_FORMAT")",
 				     device_id, profile_id, timestamp);
 
 	/* insert the entry */
 	rc = sqlite3_exec (mdb->priv->db, statement, NULL, NULL, &error_msg);
 	if (rc != SQLITE_OK) {
 		g_set_error (error,
-			     CD_MAIN_ERROR,
-			     CD_MAIN_ERROR_FAILED,
+			     CD_CLIENT_ERROR,
+			     CD_CLIENT_ERROR_INTERNAL,
 			     "SQL error: %s",
 			     error_msg);
 		sqlite3_free (error_msg);
@@ -179,7 +181,7 @@ cd_mapping_db_add (CdMappingDb *mdb,
 		goto out;
 	}
 out:
-	g_free (statement);
+	sqlite3_free (statement);
 	return ret;
 }
 /**
@@ -203,16 +205,16 @@ cd_mapping_db_update_timestamp (CdMappingDb *mdb,
 	g_debug ("CdMappingDb: update timestamp %s<=>%s",
 		 device_id, profile_id);
 	timestamp = g_get_real_time ();
-	statement = g_strdup_printf ("UPDATE mappings SET timestamp = %"G_GINT64_FORMAT
-				     " WHERE device = '%s' AND profile = '%s';",
+	statement = sqlite3_mprintf ("UPDATE mappings SET timestamp = %"G_GINT64_FORMAT
+				     " WHERE device = '%q' AND profile = '%q';",
 				     timestamp, device_id, profile_id);
 
 	/* update the entry */
 	rc = sqlite3_exec (mdb->priv->db, statement, NULL, NULL, &error_msg);
 	if (rc != SQLITE_OK) {
 		g_set_error (error,
-			     CD_MAIN_ERROR,
-			     CD_MAIN_ERROR_FAILED,
+			     CD_CLIENT_ERROR,
+			     CD_CLIENT_ERROR_INTERNAL,
 			     "SQL error: %s",
 			     error_msg);
 		sqlite3_free (error_msg);
@@ -220,7 +222,7 @@ cd_mapping_db_update_timestamp (CdMappingDb *mdb,
 		goto out;
 	}
 out:
-	g_free (statement);
+	sqlite3_free (statement);
 	return ret;
 }
 
@@ -242,16 +244,16 @@ cd_mapping_db_remove (CdMappingDb *mdb,
 	g_return_val_if_fail (mdb->priv->db != NULL, FALSE);
 
 	g_debug ("CdMappingDb: remove %s<=>%s", device_id, profile_id);
-	statement = g_strdup_printf ("DELETE FROM mappings WHERE "
-				     "device = '%s' AND profile = '%s';",
+	statement = sqlite3_mprintf ("DELETE FROM mappings WHERE "
+				     "device = '%q' AND profile = '%q';",
 				     device_id, profile_id);
 
 	/* remove the entry */
 	rc = sqlite3_exec (mdb->priv->db, statement, NULL, NULL, &error_msg);
 	if (rc != SQLITE_OK) {
 		g_set_error (error,
-			     CD_MAIN_ERROR,
-			     CD_MAIN_ERROR_FAILED,
+			     CD_CLIENT_ERROR,
+			     CD_CLIENT_ERROR_INTERNAL,
 			     "SQL error: %s",
 			     error_msg);
 		sqlite3_free (error_msg);
@@ -259,7 +261,7 @@ cd_mapping_db_remove (CdMappingDb *mdb,
 		goto out;
 	}
 out:
-	g_free (statement);
+	sqlite3_free (statement);
 	return ret;
 }
 
@@ -301,8 +303,8 @@ cd_mapping_db_get_profiles (CdMappingDb *mdb,
 	g_return_val_if_fail (mdb->priv->db != NULL, FALSE);
 
 	g_debug ("CdMappingDb: get profiles for %s", device_id);
-	statement = g_strdup_printf ("SELECT profile FROM mappings WHERE "
-				     "device = '%s' ORDER BY timestamp ASC;", device_id);
+	statement = sqlite3_mprintf ("SELECT profile FROM mappings WHERE "
+				     "device = '%q' ORDER BY timestamp ASC;", device_id);
 
 	/* remove the entry */
 	array_tmp = g_ptr_array_new_with_free_func (g_free);
@@ -313,8 +315,8 @@ cd_mapping_db_get_profiles (CdMappingDb *mdb,
 			   &error_msg);
 	if (rc != SQLITE_OK) {
 		g_set_error (error,
-			     CD_MAIN_ERROR,
-			     CD_MAIN_ERROR_FAILED,
+			     CD_CLIENT_ERROR,
+			     CD_CLIENT_ERROR_INTERNAL,
 			     "SQL error: %s",
 			     error_msg);
 		sqlite3_free (error_msg);
@@ -325,7 +327,7 @@ cd_mapping_db_get_profiles (CdMappingDb *mdb,
 	array = g_ptr_array_ref (array_tmp);
 out:
 	g_ptr_array_unref (array_tmp);
-	g_free (statement);
+	sqlite3_free (statement);
 	return array;
 }
 
@@ -350,8 +352,8 @@ cd_mapping_db_get_devices (CdMappingDb *mdb,
 	g_return_val_if_fail (mdb->priv->db != NULL, FALSE);
 
 	g_debug ("CdMappingDb: get devices for %s", profile_id);
-	statement = g_strdup_printf ("SELECT device FROM mappings WHERE "
-				     "profile = '%s' ORDER BY timestamp ASC;", profile_id);
+	statement = sqlite3_mprintf ("SELECT device FROM mappings WHERE "
+				     "profile = '%q' ORDER BY timestamp ASC;", profile_id);
 
 	/* remove the entry */
 	array_tmp = g_ptr_array_new_with_free_func (g_free);
@@ -362,8 +364,8 @@ cd_mapping_db_get_devices (CdMappingDb *mdb,
 			   &error_msg);
 	if (rc != SQLITE_OK) {
 		g_set_error (error,
-			     CD_MAIN_ERROR,
-			     CD_MAIN_ERROR_FAILED,
+			     CD_CLIENT_ERROR,
+			     CD_CLIENT_ERROR_INTERNAL,
 			     "SQL error: %s",
 			     error_msg);
 		sqlite3_free (error_msg);
@@ -374,7 +376,7 @@ cd_mapping_db_get_devices (CdMappingDb *mdb,
 	array = g_ptr_array_ref (array_tmp);
 out:
 	g_ptr_array_unref (array_tmp);
-	g_free (statement);
+	sqlite3_free (statement);
 	return array;
 }
 
@@ -416,8 +418,8 @@ cd_mapping_db_get_timestamp (CdMappingDb *mdb,
 
 	g_debug ("CdMappingDb: get checksum for %s<->%s",
 		 device_id, profile_id);
-	statement = g_strdup_printf ("SELECT timestamp FROM mappings WHERE "
-				     "device = '%s' AND profile = '%s' "
+	statement = sqlite3_mprintf ("SELECT timestamp FROM mappings WHERE "
+				     "device = '%q' AND profile = '%q' "
 				     "LIMIT 1;", device_id, profile_id);
 
 	/* query the checksum */
@@ -428,15 +430,15 @@ cd_mapping_db_get_timestamp (CdMappingDb *mdb,
 			   &error_msg);
 	if (rc != SQLITE_OK) {
 		g_set_error (error,
-			     CD_MAIN_ERROR,
-			     CD_MAIN_ERROR_FAILED,
+			     CD_CLIENT_ERROR,
+			     CD_CLIENT_ERROR_INTERNAL,
 			     "SQL error: %s",
 			     error_msg);
 		sqlite3_free (error_msg);
 		goto out;
 	}
 out:
-	g_free (statement);
+	sqlite3_free (statement);
 	return timestamp;
 }
 
